| Title: | RStudio Addin for Wrapping RMarkdown Paragraphs |
|---|---|
| Description: | Provides an RStudio addin for wrapping paragraphs in an RMarkdown document without inserting linebreaks into spans of inline R code. |
| Authors: | Tristan Mahr [aut, cre] (ORCID: <https://orcid.org/0000-0002-8890-5116>), Shir Dekel [ctb] (ORCID: <https://orcid.org/0000-0003-1773-2446>) |
| Maintainer: | Tristan Mahr <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.0.9008 |
| Built: | 2026-05-12 08:58:36 UTC |
| Source: | https://github.com/tjmahr/WrapRmd |
Evaluates all comma-separated x = y expressions in a selection. The
intended usage is for selecting all of the text between the parentheses in a
function(text = "to", select = "and", evaluate) call so that default
arguments values can be assigned to a user's global environment.
assign_argument_defaults_addin()assign_argument_defaults_addin()
Call this addin to convert \\drive\folder to //drive/folder
flip_backslashes_addin()flip_backslashes_addin()
Call this addin to preview output of an R markdown selection.
knit_selection_addin()knit_selection_addin()
Wrap text but don't insert lines breaks into inline R code
str_rmd_wrap(string, width = getOption("WrapRmd.width", 80))str_rmd_wrap(string, width = getOption("WrapRmd.width", 80))
string |
a string to wrap |
width |
desired line width. Defaults to |
This function finds all inline R code spans in a string, replaces
all non-word characters in the R spans with "Q"s, re-wraps the
string, and restores the original inline R spans.
This function preserves blanks lines between paragraphs.
a wrapped copy of the string
Call this addin to wrap paragraphs in an R Markdown document.
wrap_rmd_addin()wrap_rmd_addin()
The maximum line width can be set via options(WrapRmd.width).
Further fine tuning can be done via options WrapRmd.smart and
WrapRmd.extensions, which are passed down to
commonmark::markdown_commonmark().
Provides an RStudio addin for wrapping paragraphs in an RMarkdown document without inserting linebreaks into spans of inline R code.
Maintainer: Tristan Mahr [email protected] (ORCID)
Other contributors:
Shir Dekel [email protected] (ORCID) [contributor]